summaryrefslogtreecommitdiff
path: root/src/ai/api/ai_order.hpp
diff options
context:
space:
mode:
authoryexo <yexo@openttd.org>2009-03-04 23:12:48 +0000
committeryexo <yexo@openttd.org>2009-03-04 23:12:48 +0000
commit890c5e3ae42bd7d9f904ba6c69f3c4ac3649cdf5 (patch)
tree2ef1ec448d02c7620c9ae3185c1e07df7ef9212e /src/ai/api/ai_order.hpp
parent15e9fdd47af44f5053da3ee48bfc928696ac589c (diff)
downloadopenttd-890c5e3ae42bd7d9f904ba6c69f3c4ac3649cdf5.tar.xz
(svn r15616) -Change [API CHANGE]: Rename AIOrder::ChangeOrder() to AIOrder::SetOrderFlags().
Diffstat (limited to 'src/ai/api/ai_order.hpp')
-rw-r--r--src/ai/api/ai_order.hpp9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/ai/api/ai_order.hpp b/src/ai/api/ai_order.hpp
index 5365b56ff..c39513f19 100644
--- a/src/ai/api/ai_order.hpp
+++ b/src/ai/api/ai_order.hpp
@@ -339,9 +339,9 @@ public:
#ifndef DOXYGEN_SKIP
/**
* Internal function to help ChangeOrder.
*/
- static bool _ChangeOrder();
+ static bool _SetOrderFlags();
#endif /* DOXYGEN_SKIP */
/**
@@ -354,6 +354,11 @@ public:
* @exception AIError::ERR_OWNED_BY_ANOTHER_COMPANY
* @return True if and only if the order was changed.
*/
+ static bool SetOrderFlags(VehicleID vehicle_id, OrderPosition order_position, AIOrderFlags order_flags);
+
+ /**
+ * Deprecated, use SetOrderFlags instead.
+ */
static bool ChangeOrder(VehicleID vehicle_id, OrderPosition order_position, AIOrderFlags order_flags);
/**
@@ -339,9 +339,9 @@ public:
#ifndef DOXYGEN_SKIP
/**
- * Internal function to help ChangeOrder.
+ * Internal function to help SetOrderFlags.
*/